@@ -55,6 +55,7 @@ type CmdConfig struct {
 	BillingHistory    func() do.BillingHistoryService
 	Invoices          func() do.InvoicesService
 	Tags              func() do.TagsService
+	UptimeChecks      func() do.UptimeChecksService
 	Volumes           func() do.VolumesService
 	VolumeActions     func() do.VolumeActionsService
 	Snapshots         func() do.SnapshotsService
@@ -105,6 +106,7 @@ func NewCmdConfig(ns string, dc doctl.Config, out io.Writer, args []string, init
 			c.BillingHistory = func() do.BillingHistoryService { return do.NewBillingHistoryService(godoClient) }
 			c.Invoices = func() do.InvoicesService { return do.NewInvoicesService(godoClient) }
 			c.Tags = func() do.TagsService { return do.NewTagsService(godoClient) }
+			c.UptimeChecks = func() do.UptimeChecksService { return do.NewUptimeChecksService(godoClient) }
 			c.Volumes = func() do.VolumesService { return do.NewVolumesService(godoClient) }
 			c.VolumeActions = func() do.VolumeActionsService { return do.NewVolumeActionsService(godoClient) }
 			c.Snapshots = func() do.SnapshotsService { return do.NewSnapshotsService(godoClient) }
